@@ -2,7 +2,7 @@ from typing import TypedDict, Dict, Any
 import json
 import requests
 from .base_api_wrapper import RestAPIWrapper
-from wrappers.models_configurations.dalle_config import DALLEConfiguration
+from ..models_configurations.dalle_config import DALLEConfiguration
 
 COMPLETIONS_API_URL = "https://api.openai.com/v1/images/generations"
 
@@ -30,12 +30,16 @@ class DALLEWrapper(RestAPIWrapper):
 
     def _parse_response(self, response: Dict[str, Any]) -> str:
         images = []
+        images_path = []
         data = response['data']
     
         for idx, item in enumerate(data):
             response = requests.get(item['url'])
             images.append(response.content)
+            
             with open(f"image_{idx}.jpg", "wb") as f:
                 f.write(response.content)
+            images_path.append(f"image_{idx}.jpg")
 
-        return images
\ No newline at end of file
+        return {'images': images,
+                'images_path': images_path}
\ No newline at end of file
